pub struct ImageInfo {
pub buffer: Vec<RGBA8>,
pub width: usize,
pub height: usize,
}Fields
buffer: Vec<RGBA8>width: usizeWidth in pixels
height: usizeHeight in pixels
Implementations
Sourceimpl ImageInfo
impl ImageInfo
Sourcepub fn to_png(&self, quality: u8) -> Result<Vec<u8>, ImageError>
pub fn to_png(&self, quality: u8) -> Result<Vec<u8>, ImageError>
Optimize image to png, the quality is min 0, max 100, which means best effort, and never aborts the process.
Sourcepub fn to_avif(&self, quality: u8, speed: u8) -> Result<Vec<u8>, ImageError>
pub fn to_avif(&self, quality: u8, speed: u8) -> Result<Vec<u8>, ImageError>
Optimize image to avif.
speed accepts a value in the range 0-10, where 0 is the slowest and 10 is the fastest.
quality accepts a value in the range 0-100, where 0 is the worst and 100 is the best.
Sourcepub fn to_mozjpeg(&self, quality: u8) -> Result<Vec<u8>, ImageError>
pub fn to_mozjpeg(&self, quality: u8) -> Result<Vec<u8>, ImageError>
Optimize image to jpeg, the quality 60-80 are recommended.